@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2019, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -25,6 +25,7 @@ import georegression.struct.line.LineParametric2D_F64;
 import georegression.struct.line.LinePolar2D_F64;
 import georegression.struct.line.LineSegment2D_F64;
 import georegression.struct.point.Point2D_F64;
+import org.jetbrains.annotations.Nullable;
 
 /**
  * Various functions related to lines
@@ -76,7 +77,7 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) line in parametric notation.  If null a new instance will be created.
 	 * @return Converted line in parametric notation
 	 */
-	public static LineParametric2D_F64 convert( LinePolar2D_F64 src , LineParametric2D_F64 ret )
+	public static LineParametric2D_F64 convert( LinePolar2D_F64 src , @Nullable LineParametric2D_F64 ret )
 	{
 		if( ret == null )
 			ret = new LineParametric2D_F64();
@@ -84,8 +85,8 @@ public class UtilLine2D_F64 {
 		double c = (double) Math.cos(src.angle);
 		double s = (double) Math.sin(src.angle);
 
-		ret.p.set(c*src.distance,s*src.distance);
-		ret.slope.set(-s,c);
+		ret.p.setTo(c*src.distance,s*src.distance);
+		ret.slope.setTo(-s,c);
 
 		return ret;
 	}
@@ -97,7 +98,7 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) line in general notation.  If null a new instance will be created.
 	 * @return Converted line in general notation
 	 */
-	public static LineGeneral2D_F64 convert( LinePolar2D_F64 src , LineGeneral2D_F64 ret )
+	public static LineGeneral2D_F64 convert( LinePolar2D_F64 src , @Nullable LineGeneral2D_F64 ret )
 	{
 		if( ret == null )
 			ret = new LineGeneral2D_F64();
@@ -119,7 +120,7 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) line in polar notation.  If null a new instance will be created.
 	 * @return Converted line in polar notation
 	 */
-	public static LinePolar2D_F64 convert( LineGeneral2D_F64 src , LinePolar2D_F64 ret )
+	public static LinePolar2D_F64 convert( LineGeneral2D_F64 src , @Nullable LinePolar2D_F64 ret )
 	{
 		if( ret == null )
 			ret = new LinePolar2D_F64();
@@ -142,13 +143,13 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) line in parametric notation.  If null a new instance will be created.
 	 * @return Converted line in parametric notation
 	 */
-	public static LineParametric2D_F64 convert( LineSegment2D_F64 src , LineParametric2D_F64 ret )
+	public static LineParametric2D_F64 convert( LineSegment2D_F64 src , @Nullable LineParametric2D_F64 ret )
 	{
 		if( ret == null )
 			ret = new LineParametric2D_F64();
 
-		ret.p.set(src.a);
-		ret.slope.set(src.slopeX(),src.slopeY());
+		ret.p.setTo(src.a);
+		ret.slope.setTo(src.slopeX(),src.slopeY());
 
 		return ret;
 	}
@@ -160,7 +161,7 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) line in general notation. If null a new instance will be created.
 	 * @return Line in general notation
 	 */
-	public static LineGeneral2D_F64 convert( LineSegment2D_F64 src , LineGeneral2D_F64 ret )
+	public static LineGeneral2D_F64 convert( LineSegment2D_F64 src , @Nullable LineGeneral2D_F64 ret )
 	{
 		return convert(src.a,src.b,ret);
 	}
@@ -173,7 +174,7 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) line in general notation. If null a new instance will be created.
 	 * @return Line in general notation
 	 */
-	public static LineGeneral2D_F64 convert( Point2D_F64 a , Point2D_F64 b , LineGeneral2D_F64 ret )
+	public static LineGeneral2D_F64 convert( Point2D_F64 a , Point2D_F64 b , @Nullable LineGeneral2D_F64 ret )
 	{
 		if( ret == null )
 			ret = new LineGeneral2D_F64();
@@ -194,12 +195,12 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) Storage for new line.. If null a new instance will be created.
 	 * @return The resulting line
 	 */
-	public static LineParametric2D_F64 convert( Point2D_F64 a , Point2D_F64 b , LineParametric2D_F64 ret )
+	public static LineParametric2D_F64 convert( Point2D_F64 a , Point2D_F64 b , @Nullable LineParametric2D_F64 ret )
 	{
 		if( ret == null )
 			ret = new LineParametric2D_F64();
 
-		ret.p.set(a);
+		ret.p.setTo(a);
 		ret.slope.x = b.x-a.x;
 		ret.slope.y = b.y-a.y;
 
@@ -214,12 +215,12 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) Storage for new line.. If null a new instance will be created.
 	 * @return The resulting line
 	 */
-	public static LineParametric2D_F64 convert( Point2D_F64 a , double angle , LineParametric2D_F64 ret )
+	public static LineParametric2D_F64 convert( Point2D_F64 a , double angle , @Nullable LineParametric2D_F64 ret )
 	{
 		if( ret == null )
 			ret = new LineParametric2D_F64();
 
-		ret.p.set(a);
+		ret.p.setTo(a);
 		ret.slope.x = Math.cos(angle);
 		ret.slope.y = Math.sin(angle);
 
@@ -233,7 +234,7 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) line in polar notation. If null a new instance will be created.
 	 * @return Line in polar notation
 	 */
-	public static LinePolar2D_F64 convert( LineParametric2D_F64 src , LinePolar2D_F64 ret )
+	public static LinePolar2D_F64 convert( LineParametric2D_F64 src , @Nullable LinePolar2D_F64 ret )
 	{
 		if( ret == null )
 			ret = new LinePolar2D_F64();
@@ -257,7 +258,7 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) line in general notation.  If null a new instance will be created.
 	 * @return Converted line in general notation
 	 */
-	public static LineGeneral2D_F64 convert( LineParametric2D_F64 src , LineGeneral2D_F64 ret ) {
+	public static LineGeneral2D_F64 convert( LineParametric2D_F64 src , @Nullable LineGeneral2D_F64 ret ) {
 		if( ret == null ) {
 			ret = new LineGeneral2D_F64();
 		}
@@ -276,7 +277,7 @@ public class UtilLine2D_F64 {
 	 * @param ret (output) line in parametric notation.  If null a new instance will be created.
 	 * @return Converted line in parametric notation
 	 */
-	public static LineParametric2D_F64 convert( LineGeneral2D_F64 src ,  LineParametric2D_F64 ret ) {
+	public static LineParametric2D_F64 convert( LineGeneral2D_F64 src ,  @Nullable LineParametric2D_F64 ret ) {
 		if( ret == null ) {
 			ret = new LineParametric2D_F64();
 		}
@@ -295,4 +296,43 @@ public class UtilLine2D_F64 {
 
 		return ret;
 	}
+
+	/**
+	 * Computes a signed area for the 3 point triangle. Useful when testing the relationship between line segments.
+	 *
+	 * See: Computational Geometry in C. 2nd Ed. Section 1.5
+	 *
+	 * @return a signed area of the triangle
+	 */
+	public static double area2(Point2D_F64 a, Point2D_F64 b, Point2D_F64 c) {
+		return (b.x - a.x)*(c.y - a.y) - (c.x - a.x)*(b.y - a.y);
+	}
+
+	public static boolean isColinear(Point2D_F64 a, Point2D_F64 b, Point2D_F64 c, double tol ) {
+		return Math.abs(area2(a,b,c)) <= tol;
+	}
+
+	/**
+	 * The three points are co-linear. Check to see if 'c' lies on the segment defined by 'a' and 'b',
+	 * but if 'c' is identical to 'a' or 'b' it is between.
+	 */
+	public static boolean isBetweenColinear(Point2D_F64 a, Point2D_F64 b, Point2D_F64 c) {
+		// use the axis with the greatest difference since it will be less prone to round off error
+		if (Math.abs(a.x-b.x) >= Math.abs(a.y-b.y)) {
+			return (a.x <= c.x && c.x <= b.x) || (a.x >= c.x && c.x >= b.x);
+		}
+		return (a.y <= c.y && c.y <= b.y) || (a.y >= c.y && c.y >= b.y);
+	}
+
+	/**
+	 * The three points are co-linear. Check to see if 'c' lies on the segment defined by 'a' and 'b',
+	 * but if 'c' is identical to 'a' or 'b' it is not between.
+	 */
+	public static boolean isBetweenColinearExclusive(Point2D_F64 a, Point2D_F64 b, Point2D_F64 c) {
+		// use the axis with the greatest difference since it will be less prone to round off error
+		if (Math.abs(a.x-b.x) >= Math.abs(a.y-b.y)) {
+			return (a.x < c.x && c.x < b.x) || (a.x > c.x && c.x > b.x);
+		}
+		return (a.y < c.y && c.y < b.y) || (a.y > c.y && c.y > b.y);
+	}
 }
