@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -34,20 +34,19 @@ public abstract class GeoTuple2D_F64 <T extends GeoTuple2D_F64> extends GeoTuple
 	public double x;
 	public double y;
 
-	public GeoTuple2D_F64( double x, double y ) {
+	protected GeoTuple2D_F64( double x, double y ) {
 		this.x = x;
 		this.y = y;
 	}
 
-	public GeoTuple2D_F64() {
-	}
+	protected GeoTuple2D_F64() {}
 
-	protected void _set( GeoTuple2D_F64 a ) {
+	protected void _setTo(GeoTuple2D_F64 a ) {
 		x = a.x;
 		y = a.y;
 	}
 
-	public void set( double x, double y ) {
+	public void setTo(double x, double y ) {
 		this.x = x;
 		this.y = y;
 	}
@@ -60,6 +59,7 @@ public abstract class GeoTuple2D_F64 <T extends GeoTuple2D_F64> extends GeoTuple
 		return ( Math.abs( this.x - x ) <= tol && Math.abs( this.y - y ) <= tol );
 	}
 
+	@Override
 	public boolean isIdentical( T t, double tol ) {
 		return ( Math.abs( this.x - t.x ) <= tol && Math.abs( this.y - t.y ) <= tol );
 	}
@@ -162,6 +162,12 @@ public abstract class GeoTuple2D_F64 <T extends GeoTuple2D_F64> extends GeoTuple
 		return dx*dx + dy*dy;
 	}
 
+	@Override
+	public void setTo(T src) {
+		this.x = src.x;
+		this.y = src.y;
+	}
+
 	@Override
 	public double distance( T t ) {
 		double dx = t.x - x;
@@ -229,10 +235,14 @@ public abstract class GeoTuple2D_F64 <T extends GeoTuple2D_F64> extends GeoTuple
 
 	@Override
 	public boolean equals(Object obj) {
+		if(this == obj)
+			return true;
+
 		if( this.getClass() != obj.getClass() )
 			return false;
-		GeoTuple2D_F64 p = (GeoTuple2D_F64)obj;
-		return Double.compare(x,p.x)==0 && Double.compare(y,p.y)==0;
+
+		var o = (GeoTuple2D_F64)obj;
+		return Double.compare(x,o.x)==0 && Double.compare(y,o.y)==0;
 	}
 
 	public boolean isNaN() {
