@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2018, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -31,14 +31,14 @@ public class Point2D_F64 extends GeoTuple2D_F64<Point2D_F64> {
 	}
 
 	public Point2D_F64( double x, double y ) {
-		set( x, y );
+		setTo( x, y );
 	}
 
 	public Point2D_F64() {
 	}
 
 	public Point2D_F64( Point2D_F64 pt ) {
-		set( pt.x, pt.y );
+		setTo( pt.x, pt.y );
 	}
 
 	@Override
@@ -46,8 +46,9 @@ public class Point2D_F64 extends GeoTuple2D_F64<Point2D_F64> {
 		return new Point2D_F64();
 	}
 
-	public void set( Point2D_F64 orig ) {
-		_set( orig );
+	@Override
+	public void setTo( Point2D_F64 orig ) {
+		_setTo( orig );
 	}
 
 	@Override
