@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -42,12 +42,7 @@ public class Point2D_I16 extends GeoTuple_I32<Point2D_I16> {
 	public Point2D_I16() {
 	}
 
-	public void set( Point2D_I16 pt ) {
-		this.x = pt.x;
-		this.y = pt.y;
-	}
-
-	public void set( int x, int y ) {
+	public void setTo(int x, int y ) {
 		this.x = (short)x;
 		this.y = (short)y;
 	}
@@ -72,6 +67,12 @@ public class Point2D_I16 extends GeoTuple_I32<Point2D_I16> {
 		return this.x == x && this.y == y;
 	}
 
+	@Override
+	public void setTo(Point2D_I16 src) {
+		this.x = src.x;
+		this.y = src.y;
+	}
+
 	@Override
 	public int getIdx( int index ) {
 		if (index == 0)
@@ -105,6 +106,7 @@ public class Point2D_I16 extends GeoTuple_I32<Point2D_I16> {
 		return new Point2D_I16();
 	}
 
+	@Override
 	public Point2D_I16 copy() {
 		return new Point2D_I16( x, y );
 	}
@@ -115,11 +117,15 @@ public class Point2D_I16 extends GeoTuple_I32<Point2D_I16> {
 	}
 
 	@Override
-	public boolean equals(Object o) {
-		if (this == o) return true;
-		if (o == null || getClass() != o.getClass()) return false;
-		Point2D_I16 that = (Point2D_I16) o;
-		return x == that.x && y == that.y;
+	public boolean equals(Object obj) {
+		if(this == obj)
+			return true;
+
+		if(!(obj instanceof Point2D_I16))
+			return false;
+
+		var o = (Point2D_I16) obj;
+		return x == o.x && y == o.y;
 	}
 
 	@Override
