@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -39,15 +39,9 @@ public class Point2D_I32 extends GeoTuple_I32<Point2D_I32> {
 		this.y = orig.y;
 	}
 
-	public Point2D_I32() {
-	}
+	public Point2D_I32() {}
 
-	public void set( Point2D_I32 v ) {
-		this.x = v.x;
-		this.y = v.y;
-	}
-
-	public void set( int x, int y ) {
+	public void setTo(int x, int y ) {
 		this.x = x;
 		this.y = y;
 	}
@@ -113,6 +107,12 @@ public class Point2D_I32 extends GeoTuple_I32<Point2D_I32> {
 		return this.x == x && this.y == y;
 	}
 
+	@Override
+	public void setTo(Point2D_I32 src) {
+		this.x = src.x;
+		this.y = src.y;
+	}
+
 	@Override
 	public int getIdx( int index ) {
 		if( index == 0 )
@@ -136,6 +136,7 @@ public class Point2D_I32 extends GeoTuple_I32<Point2D_I32> {
 		System.out.println(toString());
 	}
 
+	@Override
 	public Point2D_I32 copy() {
 		return new Point2D_I32( this );
 	}
@@ -160,8 +161,8 @@ public class Point2D_I32 extends GeoTuple_I32<Point2D_I32> {
 
 	@Override
 	public boolean equals(Object obj) {
-		if( this.getClass() != obj.getClass() )
-			return false;
+		if (this == obj) return true;
+		if( !(obj instanceof Point2D_I32)) return false;
 		Point2D_I32 p = (Point2D_I32)obj;
 		return x==p.x&&y==p.y;
 	}
