@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -41,9 +41,7 @@ public class Point3D_I32 extends GeoTuple_I32<Point3D_I32> {
 		this.z = z;
 	}
 
-	public Point3D_I32() {
-	}
-
+	public Point3D_I32() {}
 
 	@Override
 	public Point3D_I32 copy() {
@@ -73,13 +71,14 @@ public class Point3D_I32 extends GeoTuple_I32<Point3D_I32> {
 			throw new RuntimeException("Invalid index "+index);
 	}
 
-	public void set(int x, int y, int z) {
+	public void setTo(int x, int y, int z) {
 		this.x = x;
 		this.y = y;
 		this.z = z;
 	}
 
-	public void set( Point3D_I32 p ) {
+	@Override
+	public void setTo(Point3D_I32 p ) {
 		this.x = p.x;
 		this.y = p.y;
 		this.z = p.z;
@@ -130,9 +129,14 @@ public class Point3D_I32 extends GeoTuple_I32<Point3D_I32> {
 
 	@Override
 	public boolean equals(Object obj) {
-		if( this.getClass() != obj.getClass() )
-			return false;
+		if (this == obj) return true;
+		if( !(obj instanceof Point3D_I32)) return false;
 		Point3D_I32 p = (Point3D_I32)obj;
 		return x==p.x&&y==p.y&&z==p.z;
 	}
+
+	@Override
+	public int hashCode() {
+		return Integer.hashCode(x+y+z);
+	}
 }
