@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -23,16 +23,16 @@ import georegression.metric.Area2D_F64;
 import georegression.metric.Intersection2D_F64;
 import georegression.struct.line.LineSegment2D_F64;
 import georegression.struct.point.Point2D_F64;
-import org.ddogleg.struct.FastQueue;
+import org.ddogleg.struct.DogArray;
 import org.ejml.ops.MatrixIO;
+import org.jetbrains.annotations.Nullable;
 
-import javax.annotation.Nullable;
 import java.io.Serializable;
 import java.text.DecimalFormat;
 import java.util.ArrayList;
 import java.util.List;
 
-import static org.ejml.UtilEjml.fancyStringF;
+import static org.ejml.UtilEjml.fancyString;
 
 /**
  * Describes a polygon in 2D.
@@ -42,56 +42,56 @@ import static org.ejml.UtilEjml.fancyStringF;
 public class Polygon2D_F64 implements Serializable {
 
 	// vertexes in the polygon
-	public FastQueue<Point2D_F64> vertexes;
+	public DogArray<Point2D_F64> vertexes;
 
 	public Polygon2D_F64( double[][] a ) {
 		this(a.length);
 
 		for (int i = 0; i < a.length; i++) {
-			vertexes.get(i).set(a[i][0], a[i][1]);
+			vertexes.get(i).setTo(a[i][0], a[i][1]);
 		}
 	}
 
 	public Polygon2D_F64( Polygon2D_F64 a ) {
-		vertexes = new FastQueue<>(a.size(),Point2D_F64::new);
+		vertexes = new DogArray<>(a.size(),Point2D_F64::new);
 		for (int i = 0; i < a.size(); i++) {
-			vertexes.grow().set(a.get(i));
+			vertexes.grow().setTo(a.get(i));
 		}
 	}
 
 	public Polygon2D_F64( int numVertexes ) {
-		vertexes = new FastQueue<>(numVertexes, Point2D_F64::new);
+		vertexes = new DogArray<>(numVertexes, Point2D_F64::new);
 
-		vertexes.growArray(numVertexes);
+		vertexes.reserve(numVertexes);
 		vertexes.size = numVertexes;
 	}
 
-	public Polygon2D_F64( double... points ) {
-		if( points.length % 2 == 1 )
+	public Polygon2D_F64( double... xy ) {
+		if( xy.length % 2 == 1 )
 			throw new IllegalArgumentException("Expected an even number");
-		vertexes = new FastQueue<>(points.length/2,Point2D_F64::new);
-		vertexes.growArray(points.length/2);
-		vertexes.size = points.length/2;
+		vertexes = new DogArray<>(xy.length/2,Point2D_F64::new);
+		vertexes.reserve(xy.length/2);
+		vertexes.size = xy.length/2;
 
 		int count = 0;
-		for (int i = 0; i < points.length; i += 2) {
-			vertexes.data[count++].set( points[i],points[i+1]);
+		for (int i = 0; i < xy.length; i += 2) {
+			vertexes.data[count++].setTo( xy[i],xy[i+1]);
 		}
 	}
 
 	public Polygon2D_F64() {
-		vertexes = new FastQueue<>(Point2D_F64::new);
+		vertexes = new DogArray<>(Point2D_F64::new);
 	}
 
-	public void set( Polygon2D_F64 orig ) {
+	public void setTo(Polygon2D_F64 orig ) {
 		vertexes.resize(orig.size());
 		for (int i = 0; i < orig.size(); i++) {
-			vertexes.data[i].set( orig.vertexes.data[i]);
+			vertexes.data[i].setTo( orig.vertexes.data[i]);
 		}
 	}
 
 	public void set( int index , double x , double y ) {
-		vertexes.data[index].set(x,y);
+		vertexes.data[index].setTo(x,y);
 	}
 
 	/**
@@ -129,17 +129,17 @@ public class Polygon2D_F64 implements Serializable {
 	 * Returns true if the point is inside the polygon.  Points along the border are ambiguously considered inside
 	 * or outside.
 	 *
-	 * @see Intersection2D_F64#containConcave(Polygon2D_F64, Point2D_F64)
-	 * @see Intersection2D_F64#containConcave(Polygon2D_F64, Point2D_F64)
+	 * @see Intersection2D_F64#containsConcave(Polygon2D_F64, Point2D_F64)
+	 * @see Intersection2D_F64#containsConcave(Polygon2D_F64, Point2D_F64)
 	 *
 	 * @param p A point
 	 * @return true if inside and false if outside
 	 */
 	public boolean isInside( Point2D_F64 p ) {
 		if( isConvex() ) {
-			return Intersection2D_F64.containConvex(this,p);
+			return Intersection2D_F64.containsConvex(this,p);
 		} else {
-			return Intersection2D_F64.containConcave(this,p);
+			return Intersection2D_F64.containsConcave(this,p);
 		}
 	}
 
@@ -167,6 +167,15 @@ public class Polygon2D_F64 implements Serializable {
 		UtilPolygons2D_F64.flip(this);
 	}
 
+	/** Creates a copy of 'this' and flips it */
+	public Polygon2D_F64 flip( @Nullable Polygon2D_F64 storage ) {
+		if (storage==null)
+			storage = new Polygon2D_F64(this.size());
+		storage.setTo(this);
+		storage.flip();
+		return storage;
+	}
+
 	/**
 	 * Returns the line/edge defined by vertex index and index+1.
 	 * @param index Index of the line
@@ -178,8 +187,8 @@ public class Polygon2D_F64 implements Serializable {
 
 		int j = (index+1)%vertexes.size;
 
-		storage.a.set(get(index));
-		storage.b.set(get(j));
+		storage.a.setTo(get(index));
+		storage.b.setTo(get(j));
 
 		return storage;
 	}
@@ -212,22 +221,22 @@ public class Polygon2D_F64 implements Serializable {
 	 * to points in the list are saved.
 	 * @param list List which the polygon will be set to
 	 */
-	public void set( List<Point2D_F64> list ) {
+	public void setTo(List<Point2D_F64> list ) {
 		vertexes.resize(list.size());
 		for (int i = 0; i < list.size(); i++) {
-			vertexes.data[i].set( list.get(i));
+			vertexes.data[i].setTo( list.get(i));
 		}
 	}
 
-	@Override
-	public String toString() {
+	@Override public String toString() {
+
 		final int length = MatrixIO.DEFAULT_LENGTH;
 		DecimalFormat format = new DecimalFormat("#");
-		String out = getClass().getSimpleName()+"{ order "+vertexes.size+" : vertexes [ ";
+		String out = getClass().getSimpleName()+"{ order="+vertexes.size+", [ ";
 
 		for (int i = 0; i < vertexes.size; i++) {
 			Point2D_F64 p = vertexes.get(i);
-			out += "( "+ fancyStringF(p.x,format,length,4)+" , "+fancyStringF(p.y,format,length,4)+" ) ";
+			out += "("+ fancyString(p.x,format,false,length,4)+", "+fancyString(p.y,format,false,length,4)+") ";
 		}
 
 		out += "] }";
