@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -26,6 +26,7 @@ import georegression.struct.point.Vector3D_F64;
 import georegression.struct.se.Se2_F64;
 import georegression.struct.se.Se3_F64;
 import org.ejml.data.DMatrixRMaj;
+import org.jetbrains.annotations.Nullable;
 
 import java.util.List;
 
@@ -44,7 +45,7 @@ public class SePointOps_F64 {
 	 *               instance is created. Modified.
 	 * @return Transformed point.
 	 */
-	public static Point2D_F64 transform( Se2_F64 se, Point2D_F64 orig, Point2D_F64 result ) {
+	public static Point2D_F64 transform( Se2_F64 se, Point2D_F64 orig, @Nullable Point2D_F64 result ) {
 
 		if( result == null ) {
 			result = new Point2D_F64();
@@ -63,7 +64,7 @@ public class SePointOps_F64 {
 		return result;
 	}
 
-	public static Point2D_F64 transform( Se2_F64 se, double x, double y, Point2D_F64 result ) {
+	public static Point2D_F64 transform( Se2_F64 se, double x, double y, @Nullable Point2D_F64 result ) {
 
 		if( result == null ) {
 			result = new Point2D_F64();
@@ -78,7 +79,7 @@ public class SePointOps_F64 {
 		return result;
 	}
 
-	public static Point2D_F64 transformReverse( Se2_F64 se, Point2D_F64 orig, Point2D_F64 result ) {
+	public static Point2D_F64 transformReverse( Se2_F64 se, Point2D_F64 orig, @Nullable Point2D_F64 result ) {
 
 		if( result == null ) {
 			result = new Point2D_F64();
@@ -105,7 +106,7 @@ public class SePointOps_F64 {
 	 * @param points Array of points which are to be transformed.  Modified.
 	 * @param length The number of elements in the array that are to be processed.
 	 */
-	public static void transform( Se2_F64 se, Point2D_F64 points[], int length ) {
+	public static void transform(Se2_F64 se, Point2D_F64[] points, int length ) {
 
 		double tranX = se.getX();
 		double tranY = se.getY();
@@ -187,11 +188,11 @@ public class SePointOps_F64 {
 	 * @param dst Storage for transformed coordinate of the point. Point declared if null.  Modified.
 	 * @return Transformed point.
 	 */
-	public static Point3D_F64 transform( Se3_F64 se, Point3D_F64 src, Point3D_F64 dst ) {
+	public static Point3D_F64 transform( Se3_F64 se, Point3D_F64 src, @Nullable Point3D_F64 dst ) {
 		return transform(se,src.x, src.y, src.z, dst);
 	}
 
-	public static Point3D_F64 transform( Se3_F64 se, double x , double y, double z, Point3D_F64 dst ) {
+	public static Point3D_F64 transform( Se3_F64 se, double x , double y, double z, @Nullable Point3D_F64 dst ) {
 		if( dst == null )
 			dst = new Point3D_F64();
 
@@ -221,20 +222,27 @@ public class SePointOps_F64 {
 	 * @param dst Storage for transformed coordinate of the point. Point declared if null.  Modified.
 	 * @return Transformed point.
 	 */
-	public static Point3D_F64 transform(Se3_F64 se, Point4D_F64 src, Point3D_F64 dst ) {
+	public static Point3D_F64 transform(Se3_F64 se, Point4D_F64 src, @Nullable Point3D_F64 dst ) {
+		return transform(se, src.x, src.y, src.z, src.w, dst);
+	}
+
+	public static Point3D_F64 transform(Se3_F64 se,
+										final double x, final double y, final double z, final double w,
+										@Nullable Point3D_F64 dst ) {
 		if( dst == null )
 			dst = new Point3D_F64();
 
-		final double x = src.x/src.w;
-		final double y = src.y/src.w;
-		final double z = src.z/src.w;
+		DMatrixRMaj R = se.R;
+		Vector3D_F64 T = se.T;
 
-		DMatrixRMaj R = se.getR();
-		Vector3D_F64 T = se.getT();
+		// [R T]*X
+		dst.x = R.data[0]*x + R.data[1]*y + R.data[2]*z + T.x*w;
+		dst.y = R.data[3]*x + R.data[4]*y + R.data[5]*z + T.y*w;
+		dst.z = R.data[6]*x + R.data[7]*y + R.data[8]*z + T.z*w;
 
-		dst.x = R.data[0]*x + R.data[1]*y + R.data[2]*z + T.x;
-		dst.y = R.data[3]*x + R.data[4]*y + R.data[5]*z + T.y;
-		dst.z = R.data[6]*x + R.data[7]*y + R.data[8]*z + T.z;
+		dst.x /= w;
+		dst.y /= w;
+		dst.z /= w;
 
 		return dst;
 	}
@@ -242,15 +250,16 @@ public class SePointOps_F64 {
 	/**
 	 * Applies the transform to src, but omits the last implicit last row in dst where dst.w = src.w
 	 */
-	public static Point3D_F64 transformV(Se3_F64 se, Point4D_F64 src, Point3D_F64 dst ) {
+	public static Point3D_F64 transformV(Se3_F64 se, Point4D_F64 src, @Nullable Point3D_F64 dst ) {
+		return transformV(se,src.x, src.y, src.z, src.w, dst);
+	}
+
+	public static Point3D_F64 transformV(Se3_F64 se,
+										 final double x, final double y, final double z, final double w,
+										 @Nullable Point3D_F64 dst ) {
 		if( dst == null )
 			dst = new Point3D_F64();
 
-		final double x = src.x;
-		final double y = src.y;
-		final double z = src.z;
-		final double w = src.w;
-
 		DMatrixRMaj R = se.getR();
 		Vector3D_F64 T = se.getT();
 
@@ -276,15 +285,16 @@ public class SePointOps_F64 {
 	 * @param dst Storage for transformed coordinate of the point. Point declared if null.  Modified.
 	 * @return Transformed point.
 	 */
-	public static Point4D_F64 transform(Se3_F64 se, Point4D_F64 src, Point4D_F64 dst ) {
+	public static Point4D_F64 transform(Se3_F64 se, Point4D_F64 src, @Nullable Point4D_F64 dst ) {
+		return transform(se, src.x, src.y, src.z ,src.w, dst);
+	}
+
+	public static Point4D_F64 transform(Se3_F64 se,
+										final double x, final double y, final double z, final double w,
+										@Nullable Point4D_F64 dst ) {
 		if( dst == null )
 			dst = new Point4D_F64();
 
-		final double x = src.x;
-		final double y = src.y;
-		final double z = src.z;
-		final double w = src.w;
-
 		DMatrixRMaj R = se.getR();
 		Vector3D_F64 T = se.getT();
 
@@ -315,7 +325,7 @@ public class SePointOps_F64 {
 	 * @param origPt Original coordinate of the point.
 	 * @param tranPt Transformed coordinate of the point.
 	 */
-	public static Point3D_F64 transformReverse( Se3_F64 se, Point3D_F64 origPt, Point3D_F64 tranPt ) {
+	public static Point3D_F64 transformReverse( Se3_F64 se, Point3D_F64 origPt, @Nullable Point3D_F64 tranPt ) {
 		if( tranPt == null )
 			tranPt = new Point3D_F64();
 
