@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -38,7 +38,7 @@ public class TestFitLineParametricSvd_F64 {
 	@Test
 	void unweighted() {
 		LineParametric2D_F64 expected = new LineParametric2D_F64();
-		expected.p.set(6.5,-3.5);
+		expected.p.setTo(6.5,-3.5);
 
 		for (int i = 0; i < 16; i++) {
 			double theta = 2.0 * Math.PI * i/16;
