@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -121,7 +121,7 @@ public class TestConvertRotation3D_F64 {
 		DMatrixRMaj expected = ConvertRotation3D_F64.eulerToMatrix(type,rotA,rotB,rotC,null);
 
 		Quaternion_F64 q = ConvertRotation3D_F64.matrixToQuaternion(expected,null);
-		double euler[] = ConvertRotation3D_F64.quaternionToEuler(q,type,null);
+		double[] euler = ConvertRotation3D_F64.quaternionToEuler(q,type,null);
 
 		DMatrixRMaj found = ConvertRotation3D_F64.eulerToMatrix(type,euler[0],euler[1],euler[2],null);
 
@@ -328,7 +328,7 @@ public class TestConvertRotation3D_F64 {
 	{
 		DMatrixRMaj expected = ConvertRotation3D_F64.eulerToMatrix(type,rotA,rotB,rotC,null);
 
-		double euler[] = ConvertRotation3D_F64.matrixToEuler(expected,type,(double[])null);
+		double[] euler = ConvertRotation3D_F64.matrixToEuler(expected,type,(double[])null);
 
 		DMatrixRMaj found = ConvertRotation3D_F64.eulerToMatrix(type,euler[0],euler[1],euler[2],null);
 
@@ -444,7 +444,7 @@ public class TestConvertRotation3D_F64 {
 
 		R = ConvertRotation3D_F64.quaternionToMatrix( q, R );
 
-		p.set( 1, 0, 0 );
+		p.setTo( 1, 0, 0 );
 		GeometryMath_F64.mult( R, p, p );
 		GeometryUnitTest.assertEquals( p, 0, 0, -1, GrlConstants.TEST_F64);
 
