@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -36,6 +36,22 @@ public class TestUtilPoint3D_F64 {
 
 	Random rand = new Random(234);
 
+	@Test void findClosestIdx() {
+		List<Point3D_F64> list = new ArrayList<>();
+		assertEquals(-1, UtilPoint3D_F64.findClosestIdx(1,2,0,list,2));
+
+		list.add(new Point3D_F64(5,2,0));
+		assertEquals(-1, UtilPoint3D_F64.findClosestIdx(1,2,0,list,2));
+		assertEquals(0, UtilPoint3D_F64.findClosestIdx(1,2,0,list,4));
+
+		list.add(new Point3D_F64(5,2,0));
+		list.add(new Point3D_F64(6,2,0));
+		list.add(new Point3D_F64(8,2,0));
+
+		assertEquals(2, UtilPoint3D_F64.findClosestIdx(6,2.1,0,list,2));
+		assertEquals(-1, UtilPoint3D_F64.findClosestIdx(100,2,0,list,2));
+	}
+
 	@Test
 	void noiseNormal_single() {
 		Point3D_F64 mean = new Point3D_F64(3,4,5);
@@ -96,4 +112,19 @@ public class TestUtilPoint3D_F64 {
 		assertEquals(0,cube.getP0().distance(list.get(0)),GrlConstants.TEST_F64);
 		assertEquals(0,cube.getP1().distance(new Point3D_F64(2,3,5)),1e-8);
 	}
+
+	@Test
+	void axisLargestAbs() {
+		assertEquals(0, UtilPoint3D_F64.axisLargestAbs(new Point3D_F64(3,2,1)));
+		assertEquals(0, UtilPoint3D_F64.axisLargestAbs(new Point3D_F64(-3,2,1)));
+		assertEquals(0, UtilPoint3D_F64.axisLargestAbs(new Point3D_F64(-3,-2,-1)));
+
+		assertEquals(1, UtilPoint3D_F64.axisLargestAbs(new Point3D_F64(2,3,1)));
+		assertEquals(1, UtilPoint3D_F64.axisLargestAbs(new Point3D_F64(2,-3,1)));
+		assertEquals(1, UtilPoint3D_F64.axisLargestAbs(new Point3D_F64(-2,3,-1)));
+
+		assertEquals(2, UtilPoint3D_F64.axisLargestAbs(new Point3D_F64(2,1,3)));
+		assertEquals(2, UtilPoint3D_F64.axisLargestAbs(new Point3D_F64(2,1,-3)));
+		assertEquals(2, UtilPoint3D_F64.axisLargestAbs(new Point3D_F64(-2,-1,3)));
+	}
 }
