@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -31,8 +31,7 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
  */
 public class TestArea2D_F64 {
 
-	@Test
-	void triangle() {
+	@Test void triangle() {
 		Point2D_F64 a = new Point2D_F64(0,0);
 		Point2D_F64 b = new Point2D_F64(5,0);
 		Point2D_F64 c = new Point2D_F64(0,3);
@@ -44,8 +43,7 @@ public class TestArea2D_F64 {
 		assertEquals(expected,found,GrlConstants.TEST_F64);
 	}
 
-	@Test
-	void quadrilateral() {
+	@Test void quadrilateral() {
 		Quadrilateral_F64 q = new Quadrilateral_F64(0,0,2,0,2,3,0,3);
 
 		assertEquals(2*3,Area2D_F64.quadrilateral(q), GrlConstants.TEST_F64);
@@ -68,8 +66,7 @@ public class TestArea2D_F64 {
 	/**
 	 * Test convex caused for the simple polygon area algorithm
 	 */
-	@Test
-	void polygonSimple_convex() {
+	@Test void polygonSimple_convex() {
 		Polygon2D_F64 t = new Polygon2D_F64(0,0,5,0,0,3);
 		assertEquals(0.5*5*3,Area2D_F64.polygonSimple(t), GrlConstants.TEST_F64);
 
@@ -93,8 +90,7 @@ public class TestArea2D_F64 {
 	/**
 	 * Test concave caused for the simple polygon area algorithm
 	 */
-	@Test
-	void polygonSimple_concave() {
+	@Test void polygonSimple_concave() {
 		Polygon2D_F64 t_inside = new Polygon2D_F64(5,5, 3,3, 0,5);
 		double area_inside = Area2D_F64.polygonSimple(t_inside);
 
@@ -111,5 +107,4 @@ public class TestArea2D_F64 {
 		q.flip();
 		assertEquals(area_q_full - area_inside, Area2D_F64.polygonSimple(q), GrlConstants.TEST_F64);
 	}
-
 }
