@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -26,9 +26,11 @@ import georegression.struct.plane.PlaneGeneral3D_F64;
 import georegression.struct.plane.PlaneNormal3D_F64;
 import georegression.struct.point.Point3D_F64;
 import georegression.struct.point.Vector3D_F64;
+import georegression.struct.shapes.Box3D_F64;
 import georegression.struct.shapes.Cylinder3D_F64;
 import georegression.struct.shapes.Sphere3D_F64;
 import georegression.struct.shapes.Triangle3D_F64;
+import org.ejml.UtilEjml;
 import org.junit.jupiter.api.Test;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
@@ -76,7 +78,7 @@ public class TestDistance3D_F64 {
 		assertEquals(2,Distance3D_F64.distance( l,p ), GrlConstants.TEST_F64);
 
 		// a point on the line
-		l.getSlope().set( 1 , 0 , 0 );
+		l.getSlope().setTo( 1 , 0 , 0 );
 		assertEquals(0,Distance3D_F64.distance( l,p ), GrlConstants.TEST_F64);
 	}
 
@@ -89,14 +91,14 @@ public class TestDistance3D_F64 {
 		assertEquals(2,Distance3D_F64.distance( l,p ), GrlConstants.TEST_F64);
 
 		// a point on the line
-		p.set(1,2.5,3);
+		p.setTo(1,2.5,3);
 		assertEquals(0,Distance3D_F64.distance( l,p ), GrlConstants.TEST_F64);
 
 		// point past l.a
-		p.set(3,-1,3);
+		p.setTo(3,-1,3);
 		assertEquals( p.distance(l.a) , Distance3D_F64.distance( l,p ), GrlConstants.TEST_F64);
 		// point past l.b
-		p.set(3,5,3);
+		p.setTo(3,5,3);
 		assertEquals( p.distance(l.b) , Distance3D_F64.distance( l,p ), GrlConstants.TEST_F64);
 
 		// this was a bug
@@ -126,21 +128,21 @@ public class TestDistance3D_F64 {
 
 		// distance from origin
 		double expected = Math.sqrt(3*3 + 4*4 + 5*5);
-		double found = Distance3D_F64.distance(g,new Point3D_F64(0,0,0));
+		double found = Distance3D_F64.distanceSigned(g,new Point3D_F64(0,0,0));
 		assertEquals(-expected,found, GrlConstants.TEST_F64);
 
 		// on the plane
-		found = Distance3D_F64.distance(g,new Point3D_F64(3,4,-5));
+		found = Distance3D_F64.distanceSigned(g,new Point3D_F64(3,4,-5));
 		assertEquals(0,found, GrlConstants.TEST_F64);
 
 		// move it away from the plane
 		Vector3D_F64 v = n.n;
 		v.normalize();
-		found = Distance3D_F64.distance(g,new Point3D_F64(v.x,v.y,v.z));
+		found = Distance3D_F64.distanceSigned(g,new Point3D_F64(v.x,v.y,v.z));
 		assertEquals(-(expected-1),found, GrlConstants.TEST_F64);
 
 		// make it to the other side and see if the sign changes
-		found = Distance3D_F64.distance(g,new Point3D_F64(v.x+3,v.y+4,v.z-5));
+		found = Distance3D_F64.distanceSigned(g,new Point3D_F64(v.x+3,v.y+4,v.z-5));
 		assertEquals(1,found, GrlConstants.TEST_F64);
 	}
 
@@ -190,4 +192,18 @@ public class TestDistance3D_F64 {
 
 		assertEquals(-2,found,GrlConstants.TEST_F64);
 	}
+
+	@Test void scoreIoU_box() {
+		// area = 24
+		var A = new Box3D_F64(-1,-1,-1,2,1,3);
+		// area = 8
+		var B = new Box3D_F64(-2,-2,-2,0,0,0);
+
+		double expected = 1.0/(24+8-1);
+		assertEquals(expected, Distance3D_F64.scoreIoU(A,B), UtilEjml.TEST_F64);
+
+		// Test no intersection
+		var C = new Box3D_F64(10,-2,-9,12,-1,-8);
+		assertEquals(0.0, Distance3D_F64.scoreIoU(A,C), UtilEjml.TEST_F64);
+	}
 }
