@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -34,6 +34,7 @@ import georegression.struct.shapes.Rectangle2D_F64;
 import georegression.struct.shapes.RectangleLength2D_F64;
 import georegression.transform.se.SePointOps_F64;
 import org.ejml.UtilEjml;
+import org.jetbrains.annotations.Nullable;
 import org.junit.jupiter.api.Test;
 
 import java.util.Random;
@@ -47,55 +48,75 @@ import static org.junit.jupiter.api.Assertions.*;
 public class TestIntersection2D_F64 {
 	Random rand = new Random( 234 );
 
-	@Test
-	void containConvex() {
+	@Test void containsConvex() {
 		Polygon2D_F64 poly = new Polygon2D_F64(4);
-		poly.vertexes.data[0].set(-1,-1);
-		poly.vertexes.data[1].set(1, -1);
-		poly.vertexes.data[2].set(1, 1);
-		poly.vertexes.data[3].set(-1, 1);
+		poly.vertexes.data[0].setTo(-1,-1);
+		poly.vertexes.data[1].setTo(1, -1);
+		poly.vertexes.data[2].setTo(1, 1);
+		poly.vertexes.data[3].setTo(-1, 1);
 
 		Point2D_F64 online = new Point2D_F64(1,-1);
 		Point2D_F64 inside = new Point2D_F64(0.5,0.5);
 		Point2D_F64 outside = new Point2D_F64(1.5,0.5);
 
-		assertFalse(Intersection2D_F64.containConvex(poly,online));
-		assertTrue(Intersection2D_F64.containConvex(poly,inside));
-		assertFalse(Intersection2D_F64.containConvex(poly,outside));
+		assertFalse(Intersection2D_F64.containsConvex(poly,online));
+		assertTrue(Intersection2D_F64.containsConvex(poly,inside));
+		assertFalse(Intersection2D_F64.containsConvex(poly,outside));
 
 		// change the order of the vertexes
 		poly.flip();
 
-		assertFalse(Intersection2D_F64.containConvex(poly,online));
-		assertTrue(Intersection2D_F64.containConvex(poly,inside));
-		assertFalse(Intersection2D_F64.containConvex(poly,outside));
+		assertFalse(Intersection2D_F64.containsConvex(poly,online));
+		assertTrue(Intersection2D_F64.containsConvex(poly,inside));
+		assertFalse(Intersection2D_F64.containsConvex(poly,outside));
 	}
 
-	@Test
-	void containConcave_rectangle() {
+	@Test void containsConvex2() {
 		Polygon2D_F64 poly = new Polygon2D_F64(4);
-		poly.vertexes.data[0].set(-1,-1);
-		poly.vertexes.data[1].set(1, -1);
-		poly.vertexes.data[2].set(1, 1);
-		poly.vertexes.data[3].set(-1, 1);
+		poly.vertexes.data[0].setTo(-1,-1);
+		poly.vertexes.data[1].setTo(1, -1);
+		poly.vertexes.data[2].setTo(1, 1);
+		poly.vertexes.data[3].setTo(-1, 1);
 
-		assertTrue(Intersection2D_F64.containConcave(poly, new Point2D_F64(0, 0)));
+		Point2D_F64 online = new Point2D_F64(1,-1);
+		Point2D_F64 inside = new Point2D_F64(0.5,0.5);
+		Point2D_F64 outside = new Point2D_F64(1.5,0.5);
+
+		assertTrue(Intersection2D_F64.containsConvex2(poly,online.x,online.y));
+		assertTrue(Intersection2D_F64.containsConvex2(poly,inside.x,inside.y));
+		assertFalse(Intersection2D_F64.containsConvex2(poly,outside.x,outside.y));
+
+		// change the order of the vertexes
+		poly.flip();
+
+		assertTrue(Intersection2D_F64.containsConvex2(poly,online.x,online.y));
+		assertTrue(Intersection2D_F64.containsConvex2(poly,inside.x,inside.y));
+		assertFalse(Intersection2D_F64.containsConvex2(poly,outside.x,outside.y));
+	}
+
+	@Test void containsConcave_rectangle() {
+		Polygon2D_F64 poly = new Polygon2D_F64(4);
+		poly.vertexes.data[0].setTo(-1,-1);
+		poly.vertexes.data[1].setTo(1, -1);
+		poly.vertexes.data[2].setTo(1, 1);
+		poly.vertexes.data[3].setTo(-1, 1);
+
+		assertTrue(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0, 0)));
 
 		// perimeter cases intentionally not handled here
 
-		assertFalse(Intersection2D_F64.containConcave(poly, new Point2D_F64(2, 0)));
-		assertFalse(Intersection2D_F64.containConcave(poly, new Point2D_F64(-2, 0)));
-		assertFalse(Intersection2D_F64.containConcave(poly, new Point2D_F64(0, 2)));
-		assertFalse(Intersection2D_F64.containConcave(poly, new Point2D_F64(0, -2)));
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(2, 0)));
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(-2, 0)));
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0, 2)));
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0, -2)));
 	}
 
-	@Test
-	void contains_quadrilateral() {
+	@Test void contains_quadrilateral() {
 		Quadrilateral_F64 quad = new Quadrilateral_F64();
-		quad.a.set(-1, -1);
-		quad.b.set(1, -1);
-		quad.c.set(1, 1);
-		quad.d.set(-1, 1);
+		quad.a.setTo(-1, -1);
+		quad.b.setTo(1, -1);
+		quad.c.setTo(1, 1);
+		quad.d.setTo(-1, 1);
 
 		assertTrue(Intersection2D_F64.contains(quad, new Point2D_F64(0, 0)));
 
@@ -107,8 +128,7 @@ public class TestIntersection2D_F64 {
 		assertFalse(Intersection2D_F64.contains(quad, new Point2D_F64(0, -2)));
 	}
 
-	@Test
-	void containTriangle() {
+	@Test void containTriangle() {
 		Point2D_F64 a = new Point2D_F64(1,2);
 		Point2D_F64 b = new Point2D_F64(4,2);
 		Point2D_F64 c = new Point2D_F64(4,5);
@@ -120,8 +140,7 @@ public class TestIntersection2D_F64 {
 		assertFalse(Intersection2D_F64.containTriangle(a, b, c, outside));
 	}
 
-	@Test
-	void containEllipseRotated() {
+	@Test void containEllipseRotated() {
 
 		EllipseRotated_F64 ellipse = new EllipseRotated_F64(5,6,4,3, GrlConstants.PId2);
 
@@ -134,29 +153,53 @@ public class TestIntersection2D_F64 {
 		assertFalse(Intersection2D_F64.contains(ellipse,5+3 + GrlConstants.TEST_F64,6));
 	}
 
-	@Test
-	void containConcave_concave() {
+	/** Polygon has no elements. This caused an exception at one point */
+	@Test void containConcave_zero_one() {
+		// there is no polygon so it can't be inside
+		var poly = new Polygon2D_F64(0);
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0,0.5)));
+
+		// a single point and the test point is identical. This is ambiguous. For now we define it ot be false
+		poly.vertexes.grow().setTo(0, 0.5);
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0,0.5)));
+	}
+
+	/** See if it handles line points. A.k.a. line segment */
+	@Test void containConcave_two() {
+		var poly = new Polygon2D_F64(0);
+		poly.vertexes.grow().setTo(0,0);
+		poly.vertexes.grow().setTo(1,0);
+
+		// Point not on the line
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0,0.5)));
+
+		// The current implementation doesn't define behavior for points on the line. We will just call
+		// this and make sure it doesn't throw an exception
+		Intersection2D_F64.containsConcave(poly, new Point2D_F64(0.5,0));
+		Intersection2D_F64.containsConcave(poly, new Point2D_F64(0.0,0));
+	}
+
+	@Test void containConcave_concave() {
 		Polygon2D_F64 poly = new Polygon2D_F64(5);
-		poly.vertexes.data[0].set(-1,-1);
-		poly.vertexes.data[1].set( 0, 0);
-		poly.vertexes.data[2].set(1, -1);
-		poly.vertexes.data[3].set(1, 1);
-		poly.vertexes.data[4].set(-1, 1);
+		poly.vertexes.data[0].setTo(-1,-1);
+		poly.vertexes.data[1].setTo( 0, 0);
+		poly.vertexes.data[2].setTo(1, -1);
+		poly.vertexes.data[3].setTo(1, 1);
+		poly.vertexes.data[4].setTo(-1, 1);
 
-		assertTrue(Intersection2D_F64.containConcave(poly, new Point2D_F64(0,0.5)));
-		assertTrue(Intersection2D_F64.containConcave(poly, new Point2D_F64(-0.75,-0.25)));
-		assertTrue(Intersection2D_F64.containConcave(poly, new Point2D_F64(0.75,-0.25)));
+		assertTrue(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0,0.5)));
+		assertTrue(Intersection2D_F64.containsConcave(poly, new Point2D_F64(-0.75,-0.25)));
+		assertTrue(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0.75,-0.25)));
 
-		assertFalse(Intersection2D_F64.containConcave(poly, new Point2D_F64(0,-0.5)));
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0,-0.5)));
 
-		assertFalse(Intersection2D_F64.containConcave(poly, new Point2D_F64(2,0)));
-		assertFalse(Intersection2D_F64.containConcave(poly, new Point2D_F64(-2,0)));
-		assertFalse(Intersection2D_F64.containConcave(poly, new Point2D_F64(0, 2)));
-		assertFalse(Intersection2D_F64.containConcave(poly, new Point2D_F64(0, -2)));
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(2,0)));
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(-2,0)));
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0, 2)));
+		assertFalse(Intersection2D_F64.containsConcave(poly, new Point2D_F64(0, -2)));
 	}
 	
-	@Test
-	void intersection_ls_to_ls() {
+	@Test void intersection_ls_to_ls() {
 		// check positive, none pathological cases
 		checkIntersection(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(2, 0, 2, 3), new Point2D_F64(2, 2));
 		checkIntersection(new LineSegment2D_F64(0, 2, 2, 0), new LineSegment2D_F64(0, 0, 2, 2), new Point2D_F64(1, 1));
@@ -175,24 +218,67 @@ public class TestIntersection2D_F64 {
 		checkIntersection(new LineSegment2D_F64(0, 2, 0, 5), new LineSegment2D_F64(0, 1, 0, 3), null);
 	}
 
-	public void checkIntersection( LineSegment2D_F64 a, LineSegment2D_F64 b, Point2D_F64 expected ) {
+	public void checkIntersection( LineSegment2D_F64 a, LineSegment2D_F64 b, @Nullable Point2D_F64 expected ) {
 		Point2D_F64 found = Intersection2D_F64.intersection( a, b, null );
 		if( found == null )
-			assertTrue( expected == null );
+			assertNull(expected);
 		else {
+			assertNotNull(expected);
 			assertEquals( found.getX(), expected.getX(), GrlConstants.TEST_F64);
 			assertEquals( found.getY(), expected.getY(), GrlConstants.TEST_F64);
 		}
 	}
 
+	@Test void intersects_ls_to_ls() {
+		final double tol = UtilEjml.TEST_F64;
+		// check positive, none pathological cases
+		assertTrue(Intersection2D_F64.intersects(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(2, 0, 2, 3), tol));
+		assertTrue(Intersection2D_F64.intersects(new LineSegment2D_F64(0, 2, 2, 0), new LineSegment2D_F64(0, 0, 2, 2), tol));
+
+		// The end points are inclusive and should be considered an intersection
+		assertTrue(Intersection2D_F64.intersects(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(0, 0, 0, 2), tol));
+		assertTrue(Intersection2D_F64.intersects(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(2, 0, 2, 2), tol));
+		assertTrue(Intersection2D_F64.intersects(new LineSegment2D_F64(1, 0, 1, 2), new LineSegment2D_F64(0, 0, 2, 0), tol));
+
+		// check negative
+		assertFalse(Intersection2D_F64.intersects(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(0, 0, 0, 1.9), tol));
+		assertFalse(Intersection2D_F64.intersects(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(2, 0, 2, 1.9), tol));
+		assertFalse(Intersection2D_F64.intersects(new LineSegment2D_F64(1, 0.1, 1, 2), new LineSegment2D_F64(0, 0, 2, 0), tol));
+
+		// check parallel
+		assertTrue(Intersection2D_F64.intersects(new LineSegment2D_F64(0, 2, 0, 5), new LineSegment2D_F64(0, 1, 0, 3), tol));
+		assertFalse(Intersection2D_F64.intersects(new LineSegment2D_F64(0, 2, 0, 5), new LineSegment2D_F64(0, -0.5, 0, 1.5), tol));
+	}
+
+	@Test void intersects2_ls_to_ls() {
+		final double tol = UtilEjml.TEST_F64;
+		// check positive, none pathological cases
+		assertTrue(Intersection2D_F64.intersects2(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(2, 0, 2, 3), tol));
+		assertTrue(Intersection2D_F64.intersects2(new LineSegment2D_F64(0, 2, 2, 0), new LineSegment2D_F64(0, 0, 2, 2), tol));
+
+		// Two end points touching will not be considered an intersection
+		assertFalse(Intersection2D_F64.intersects2(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(0, 0, 0, 2), tol));
+		assertFalse(Intersection2D_F64.intersects2(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(2, 0, 2, 2), tol));
+
+		// However a line passing through an end point is an intersection
+		assertTrue(Intersection2D_F64.intersects2(new LineSegment2D_F64(1, 0, 1, 2), new LineSegment2D_F64(0, 0, 2, 0), tol));
+
+		// check clear negative
+		assertFalse(Intersection2D_F64.intersects2(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(0, 0, 0, 1.9), tol));
+		assertFalse(Intersection2D_F64.intersects2(new LineSegment2D_F64(0, 2, 2, 2), new LineSegment2D_F64(2, 0, 2, 1.9), tol));
+		assertFalse(Intersection2D_F64.intersects2(new LineSegment2D_F64(1, 0.1, 1, 2), new LineSegment2D_F64(0, 0, 2, 0), tol));
+
+		// check parallel
+		assertTrue(Intersection2D_F64.intersects2(new LineSegment2D_F64(0, 2, 0, 5), new LineSegment2D_F64(0, 1, 0, 3), tol));
+		assertFalse(Intersection2D_F64.intersects2(new LineSegment2D_F64(0, 2, 0, 5), new LineSegment2D_F64(0, -0.5, 0, 1.5), tol));
+	}
 
 	/**
 	 * Checks to see if the expected distance is returned and that the end points of the
 	 * line segment are respected.  The test cases are rotated around in a circle to test
 	 * more geometric configurations
 	 */
-	@Test
-	void intersection_p_to_ls() {
+	@Test void intersection_p_to_ls() {
 		LineParametric2D_F64 paraLine = new LineParametric2D_F64();
 		LineSegment2D_F64 target = new LineSegment2D_F64( -1, 1, 1, 1 );
 
@@ -251,41 +337,40 @@ public class TestIntersection2D_F64 {
 		assertTrue( Double.isNaN( dist ) );
 	}
 
-	@Test
-	void intersection_l_to_l_parametric_pt() {
+	@Test void intersection_l_to_l_parametric_pt() {
 		LineParametric2D_F64 a = new LineParametric2D_F64(2,3,1,0);
 		LineParametric2D_F64 b = new LineParametric2D_F64(-2,-4,0,1);
 
 		Point2D_F64 found = Intersection2D_F64.intersection(a,b,null);
+		assertNotNull(found);
 		assertEquals( -2, found.x, GrlConstants.TEST_F64);
 		assertEquals(3, found.y, GrlConstants.TEST_F64);
 
 		LineParametric2D_F64 c = new LineParametric2D_F64(-8,2,0,1);
 
-		assertTrue(null == Intersection2D_F64.intersection(b,c,null));
+		assertNull(Intersection2D_F64.intersection(b, c, null));
 	}
 
-	@Test
-	void intersection_r_to_r_parametric_pt() {
+	@Test void intersection_r_to_r_parametric_pt() {
 		LineParametric2D_F64 a = new LineParametric2D_F64(2,3,1,0);
 		LineParametric2D_F64 b = new LineParametric2D_F64(-2,-4,0,-1);
 
 		assertNull(Intersection2D_F64.intersection(a, b, true, null));
-		b.slope.set(0,1);
+		b.slope.setTo(0,1);
 		assertNull(Intersection2D_F64.intersection(a, b, true, null));
 		assertNull(Intersection2D_F64.intersection(b, a, true, null));
-		a.slope.set(-1,0);
-		b.slope.set(0,-1);
+		a.slope.setTo(-1,0);
+		b.slope.setTo(0,-1);
 		assertNull(Intersection2D_F64.intersection(a, b, true, null));
 		assertNull(Intersection2D_F64.intersection(b, a, true, null));
 
-		b.slope.set(0,1);
+		b.slope.setTo(0,1);
 		Point2D_F64 found = Intersection2D_F64.intersection(a,b,true,null);
+		assertNotNull(found);
 		assertEquals(0,found.distance(-2,3), UtilEjml.TEST_F64);
 	}
 
-	@Test
-	void intersection_l_to_l_parametric_t() {
+	@Test void intersection_l_to_l_parametric_t() {
 		LineParametric2D_F64 a = new LineParametric2D_F64(2,3,1,0);
 		LineParametric2D_F64 b = new LineParametric2D_F64(-2,-4,0,1);
 
@@ -301,8 +386,7 @@ public class TestIntersection2D_F64 {
 		assertTrue(Double.isNaN(Intersection2D_F64.intersection(b, c)));
 	}
 
-	@Test
-	void intersection_l_to_l_points() {
+	@Test void intersection_l_to_l_points() {
 		Point2D_F64 a0 = new Point2D_F64(3,20);
 		Point2D_F64 a1 = new Point2D_F64(10,20);
 		Point2D_F64 b0 = new Point2D_F64(7,5);
@@ -314,15 +398,14 @@ public class TestIntersection2D_F64 {
 		Point2D_F64 expected = Intersection2D_F64.intersection(a,b,null);
 		Point2D_F64 found = Intersection2D_F64.intersection(a0,a1,b0,b1,null);
 
-		assertTrue(expected!=null);
-		assertTrue(found!=null);
+		assertNotNull(expected);
+		assertNotNull(found);
 		assertEquals(expected.x, found.x, GrlConstants.TEST_F64);
 		assertEquals(expected.y, found.y, GrlConstants.TEST_F64);
 
 	}
 	
-	@Test
-	void intersection_l_to_l_general_3D() {
+	@Test void intersection_l_to_l_general_3D() {
 		// check two arbitrary lines
 		LineGeneral2D_F64 a = new LineGeneral2D_F64(1,2,3);
 		LineGeneral2D_F64 b = new LineGeneral2D_F64(2,-1,0.5);
@@ -340,24 +423,23 @@ public class TestIntersection2D_F64 {
 		assertEquals(0, a.A * found.x + a.B * found.y + a.C * found.z, GrlConstants.TEST_F64);
 	}
 
-	@Test
-	void intersection_l_to_l_general_2D() {
+	@Test void intersection_l_to_l_general_2D() {
 		// check two arbitrary lines
 		LineGeneral2D_F64 a = new LineGeneral2D_F64(1,2,3);
 		LineGeneral2D_F64 b = new LineGeneral2D_F64(2,-1,0.5);
 
 		Point2D_F64 found = Intersection2D_F64.intersection(a,b,(Point2D_F64)null);
+		assertNotNull(found);
 		assertEquals(0,a.A*found.x+a.B*found.y+a.C, GrlConstants.TEST_F64);
 
 		// give it two parallel lines
 		a = new LineGeneral2D_F64(1,2,3);
 		b = new LineGeneral2D_F64(1,2,0.5);
 
-		assertTrue(null == Intersection2D_F64.intersection(a, b, found));
+		assertNull(Intersection2D_F64.intersection(a, b, found));
 	}
 
-	@Test
-	void intersects_rect_corners() {
+	@Test void intersects_rect_corners() {
 		// check several positive cases
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(0,0,100,120),true);
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(10,12,99,119),true);
@@ -375,18 +457,17 @@ public class TestIntersection2D_F64 {
 		// edge cases
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(0,0,0,0),false);
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(100,120,100,120),false);
-		check(new Rectangle2D_F64(0, 0, 100, 120), new Rectangle2D_F64(-10, 0, 0, 120), false);
+		check( new Rectangle2D_F64(0, 0, 100, 120), new Rectangle2D_F64(-10, 0, 0, 120), false);
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(100,0,105,120),false);
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(0,-10,100,0),false);
-		check(new Rectangle2D_F64(0, 0, 100, 120), new Rectangle2D_F64(0, 120, 100, 125), false);
+		check( new Rectangle2D_F64(0, 0, 100, 120), new Rectangle2D_F64(0, 120, 100, 125), false);
 	}
 
 	private void check( Rectangle2D_F64 a , Rectangle2D_F64 b , boolean expected ) {
-		assertTrue(expected==Intersection2D_F64.intersects(a,b));
+		assertEquals(Intersection2D_F64.intersects(a, b), expected);
 	}
 
-	@Test
-	void intersection_rect_corners() {
+	@Test void intersection_rect_corners() {
 		// check several positive cases
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(0,0,100,120),
 				new Rectangle2D_F64(0,0,100,120));
@@ -416,9 +497,9 @@ public class TestIntersection2D_F64 {
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(0,120,100,125),null);
 	}
 
-	private void check( Rectangle2D_F64 a , Rectangle2D_F64 b , Rectangle2D_F64 expected ) {
+	private void check( Rectangle2D_F64 a , Rectangle2D_F64 b , @Nullable Rectangle2D_F64 expected ) {
 		if( expected == null ) {
-			assertFalse(Intersection2D_F64.intersection(a, b, null));
+			assertFalse(Intersection2D_F64.intersection(a, b, new Rectangle2D_F64()));
 			return;
 		}
 
@@ -431,8 +512,7 @@ public class TestIntersection2D_F64 {
 		assertEquals(expected.p1.y,found.p1.y,GrlConstants.TEST_F64);
 	}
 
-	@Test
-	void contains_rectLength_pt() {
+	@Test void contains_rectLength_pt() {
 		RectangleLength2D_F64 rect = new RectangleLength2D_F64(-10,-5,5,10);
 
 		assertTrue(Intersection2D_F64.contains(rect,-10,-5));
@@ -449,8 +529,7 @@ public class TestIntersection2D_F64 {
 		assertFalse(Intersection2D_F64.contains(rect, -6, 5));
 	}
 
-	@Test
-	void contains2_rectLength_pt() {
+	@Test void contains2_rectLength_pt() {
 		RectangleLength2D_F64 rect = new RectangleLength2D_F64(-10,-5,5,10);
 
 		assertTrue(Intersection2D_F64.contains2(rect, -10, -5));
@@ -468,8 +547,7 @@ public class TestIntersection2D_F64 {
 		assertTrue(Intersection2D_F64.contains2(rect, -6, 5));
 	}
 
-	@Test
-	void contains_rect_pt() {
+	@Test void contains_rect_pt() {
 		Rectangle2D_F64 rect = new Rectangle2D_F64(-10,-5,-5,5);
 
 		assertTrue(Intersection2D_F64.contains(rect, -10, -5));
@@ -486,8 +564,7 @@ public class TestIntersection2D_F64 {
 		assertFalse(Intersection2D_F64.contains(rect, -6, 5));
 	}
 
-	@Test
-	void contains2_rect_pt() {
+	@Test void contains2_rect_pt() {
 		Rectangle2D_F64 rect = new Rectangle2D_F64(-10,-5,-5,5);
 
 		assertTrue(Intersection2D_F64.contains2(rect, -10, -5));
@@ -505,8 +582,7 @@ public class TestIntersection2D_F64 {
 		assertTrue(Intersection2D_F64.contains2(rect, -6, 5));
 	}
 
-	@Test
-	void intersectionArea_rect_rect() {
+	@Test void intersectionArea_rect_rect() {
 		// check several positive cases
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(0,0,100,120), 100*120);
 		check( new Rectangle2D_F64(0,0,100,120),new Rectangle2D_F64(10,12,99,119), 89*107);
@@ -534,21 +610,35 @@ public class TestIntersection2D_F64 {
 		assertEquals(expected,Intersection2D_F64.intersectionArea(a,b),GrlConstants.TEST_F64);
 	}
 
-	@Test
-	void intersection_poly_to_poly() {
+	@Test void intersectionArea_poly_to_poly() {
 		Polygon2D_F64 A = new Polygon2D_F64(new double[][]{{0,0},{2,0},{2,4},{0,4}});
 		Polygon2D_F64 B = A.copy();
 
-		assertEquals(8,Intersection2D_F64.intersection(A,B), GrlConstants.TEST_SQ_F64);
+		assertEquals(8,Intersection2D_F64.intersectionArea(A,B), GrlConstants.TEST_SQ_F64);
 
 		// make sure the order doesn't matter
 		B.flip();
-		assertEquals(8,Intersection2D_F64.intersection(A,B), GrlConstants.TEST_SQ_F64);
+		assertEquals(8,Intersection2D_F64.intersectionArea(A,B), GrlConstants.TEST_SQ_F64);
 	}
 
-	@Test
-	void line_ellipse() {
+	@Test void intersection_poly_to_poly_Simple() {
+		// A should have an area of 2*4 + 2*2
+		// It's a concave polygon with no self intersections
+		Polygon2D_F64 A = new Polygon2D_F64(new double[][]{{0,0},{4,0},{4,4},{2,2},{0,4}});
+		Polygon2D_F64 B = A.copy();
 
+		assertEquals(12,Intersection2D_F64.intersectionArea(A,B), GrlConstants.TEST_SQ_F64);
+
+		// make sure the order doesn't matter
+		B.flip();
+		assertEquals(12,Intersection2D_F64.intersectionArea(A,B), GrlConstants.TEST_SQ_F64);
+
+		// Now B will be a convex polygon that the intersects left side
+		B = new Polygon2D_F64(new double[][]{{0,0},{2,0},{2,6},{0,4}});
+		assertEquals(1.5*2*2,Intersection2D_F64.intersectionArea(A,B), GrlConstants.TEST_SQ_F64);
+	}
+
+	@Test void line_ellipse() {
 		// easy cases where the ellipse is at the original aligned to the coordinate axis
 		EllipseRotated_F64 ellipse = new EllipseRotated_F64(0,0,2,1,0);
 
