@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -22,6 +22,7 @@ import georegression.struct.point.Point2D_I32;
 import georegression.struct.shapes.Polygon2D_I32;
 import georegression.struct.shapes.Rectangle2D_I32;
 import georegression.struct.shapes.RectangleLength2D_I32;
+import org.jetbrains.annotations.Nullable;
 import org.junit.jupiter.api.Test;
 
 import static org.junit.jupiter.api.Assertions.*;
@@ -34,67 +35,67 @@ public class TestIntersection2D_I32 {
 	@Test
 	void containConvex() {
 		Polygon2D_I32 poly = new Polygon2D_I32(4);
-		poly.vertexes.data[0].set(-10,-10);
-		poly.vertexes.data[1].set(10, -10);
-		poly.vertexes.data[2].set(10, 10);
-		poly.vertexes.data[3].set(-10, 10);
+		poly.vertexes.data[0].setTo(-10,-10);
+		poly.vertexes.data[1].setTo(10, -10);
+		poly.vertexes.data[2].setTo(10, 10);
+		poly.vertexes.data[3].setTo(-10, 10);
 
 		Point2D_I32 online = new Point2D_I32(10,-10);
 		Point2D_I32 inside = new Point2D_I32(5,5);
 		Point2D_I32 outside = new Point2D_I32(15,5);
 
-		assertFalse(Intersection2D_I32.containConvex(poly,online));
-		assertTrue(Intersection2D_I32.containConvex(poly,inside));
-		assertFalse(Intersection2D_I32.containConvex(poly,outside));
+		assertFalse(Intersection2D_I32.containsConvex(poly,online));
+		assertTrue(Intersection2D_I32.containsConvex(poly,inside));
+		assertFalse(Intersection2D_I32.containsConvex(poly,outside));
 
 		// change the order of the vertexes
-		poly.vertexes.data[0].set(-10, 10);
-		poly.vertexes.data[1].set(10, 10);
-		poly.vertexes.data[2].set(10, -10);
-		poly.vertexes.data[3].set(-10,-10);
+		poly.vertexes.data[0].setTo(-10, 10);
+		poly.vertexes.data[1].setTo(10, 10);
+		poly.vertexes.data[2].setTo(10, -10);
+		poly.vertexes.data[3].setTo(-10,-10);
 
-		assertFalse(Intersection2D_I32.containConvex(poly,online));
-		assertTrue(Intersection2D_I32.containConvex(poly,inside));
-		assertFalse(Intersection2D_I32.containConvex(poly,outside));
+		assertFalse(Intersection2D_I32.containsConvex(poly,online));
+		assertTrue(Intersection2D_I32.containsConvex(poly,inside));
+		assertFalse(Intersection2D_I32.containsConvex(poly,outside));
 	}
 
 	@Test
 	void containConcave_rectangle() {
 		Polygon2D_I32 poly = new Polygon2D_I32(4);
-		poly.vertexes.data[0].set(-1,-1);
-		poly.vertexes.data[1].set(1, -1);
-		poly.vertexes.data[2].set(1, 1);
-		poly.vertexes.data[3].set(-1, 1);
+		poly.vertexes.data[0].setTo(-1,-1);
+		poly.vertexes.data[1].setTo(1, -1);
+		poly.vertexes.data[2].setTo(1, 1);
+		poly.vertexes.data[3].setTo(-1, 1);
 
-		assertTrue(Intersection2D_I32.containConcave(poly, new Point2D_I32(0,0)));
+		assertTrue(Intersection2D_I32.containsConcave(poly, new Point2D_I32(0,0)));
 
 		// perimeter cases intentionally not handled here
 
-		assertFalse(Intersection2D_I32.containConcave(poly, new Point2D_I32(2,0)));
-		assertFalse(Intersection2D_I32.containConcave(poly, new Point2D_I32(-2,0)));
-		assertFalse(Intersection2D_I32.containConcave(poly, new Point2D_I32(0,2)));
-		assertFalse(Intersection2D_I32.containConcave(poly, new Point2D_I32(0,-2)));
+		assertFalse(Intersection2D_I32.containsConcave(poly, new Point2D_I32(2,0)));
+		assertFalse(Intersection2D_I32.containsConcave(poly, new Point2D_I32(-2,0)));
+		assertFalse(Intersection2D_I32.containsConcave(poly, new Point2D_I32(0,2)));
+		assertFalse(Intersection2D_I32.containsConcave(poly, new Point2D_I32(0,-2)));
 	}
 
 	@Test
 	void containConcave_concave() {
 		Polygon2D_I32 poly = new Polygon2D_I32(5);
-		poly.vertexes.data[0].set(-10,-10);
-		poly.vertexes.data[1].set( 0, 0);
-		poly.vertexes.data[2].set(10, -10);
-		poly.vertexes.data[3].set(10, 10);
-		poly.vertexes.data[4].set(-10, 10);
+		poly.vertexes.data[0].setTo(-10,-10);
+		poly.vertexes.data[1].setTo( 0, 0);
+		poly.vertexes.data[2].setTo(10, -10);
+		poly.vertexes.data[3].setTo(10, 10);
+		poly.vertexes.data[4].setTo(-10, 10);
 
-		assertTrue(Intersection2D_I32.containConcave(poly, new Point2D_I32(0,5)));
-		assertTrue(Intersection2D_I32.containConcave(poly, new Point2D_I32(-7,-2)));
-		assertTrue(Intersection2D_I32.containConcave(poly, new Point2D_I32(7,-2)));
+		assertTrue(Intersection2D_I32.containsConcave(poly, new Point2D_I32(0,5)));
+		assertTrue(Intersection2D_I32.containsConcave(poly, new Point2D_I32(-7,-2)));
+		assertTrue(Intersection2D_I32.containsConcave(poly, new Point2D_I32(7,-2)));
 
-		assertFalse(Intersection2D_I32.containConcave(poly, new Point2D_I32(0,-5)));
+		assertFalse(Intersection2D_I32.containsConcave(poly, new Point2D_I32(0,-5)));
 
-		assertFalse(Intersection2D_I32.containConcave(poly, new Point2D_I32(20,0)));
-		assertFalse(Intersection2D_I32.containConcave(poly, new Point2D_I32(-20,0)));
-		assertFalse(Intersection2D_I32.containConcave(poly, new Point2D_I32(0,20)));
-		assertFalse(Intersection2D_I32.containConcave(poly, new Point2D_I32(0,-20)));
+		assertFalse(Intersection2D_I32.containsConcave(poly, new Point2D_I32(20,0)));
+		assertFalse(Intersection2D_I32.containsConcave(poly, new Point2D_I32(-20,0)));
+		assertFalse(Intersection2D_I32.containsConcave(poly, new Point2D_I32(0,20)));
+		assertFalse(Intersection2D_I32.containsConcave(poly, new Point2D_I32(0,-20)));
 	}
 	
 	@Test
@@ -157,9 +158,9 @@ public class TestIntersection2D_I32 {
 		check( new Rectangle2D_I32(0,0,100,120),new Rectangle2D_I32(0,120,100,125),null);
 	}
 
-	private void check( Rectangle2D_I32 a , Rectangle2D_I32 b , Rectangle2D_I32 expected ) {
+	private void check( Rectangle2D_I32 a , Rectangle2D_I32 b , @Nullable Rectangle2D_I32 expected ) {
 		if( expected == null ) {
-			assertFalse(Intersection2D_I32.intersection(a, b, null));
+			assertFalse(Intersection2D_I32.intersection(a, b, new Rectangle2D_I32()));
 			return;
 		}
 
