@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -34,8 +34,8 @@ import georegression.struct.shapes.BoxLength3D_F64;
 import georegression.struct.shapes.Sphere3D_F64;
 import georegression.struct.shapes.Triangle3D_F64;
 import georegression.transform.se.SePointOps_F64;
+import org.ddogleg.struct.DogArray;
 import org.ddogleg.struct.FastArray;
-import org.ddogleg.struct.FastQueue;
 import org.ejml.UtilEjml;
 import org.junit.jupiter.api.Test;
 
@@ -54,7 +54,7 @@ public class TestIntersection3D_F64 {
 		LineParametric3D_F64 line = new LineParametric3D_F64(0,0,0,3,0,0);
 
 		Point3D_F64 found = new Point3D_F64();
-		assertTrue(Intersection3D_F64.intersect(plane, line, found));
+		assertTrue(Intersection3D_F64.intersection(plane, line, found));
 
 		assertEquals(2,found.x, GrlConstants.TEST_F64);
 		assertEquals(0,found.y, GrlConstants.TEST_F64);
@@ -69,7 +69,7 @@ public class TestIntersection3D_F64 {
 		PlaneGeneral3D_F64 general = UtilPlane3D_F64.convert(plane,(PlaneGeneral3D_F64)null);
 
 		Point3D_F64 found = new Point3D_F64();
-		assertTrue(Intersection3D_F64.intersect(general, line, found));
+		assertTrue(Intersection3D_F64.intersection(general, line, found));
 
 		assertEquals(2,found.x, GrlConstants.TEST_F64);
 		assertEquals(0,found.y, GrlConstants.TEST_F64);
@@ -83,7 +83,7 @@ public class TestIntersection3D_F64 {
 
 		LineParametric3D_F64 line = new LineParametric3D_F64();
 
-		Intersection3D_F64.intersect(a,b,line);
+		Intersection3D_F64.intersection(a,b,line);
 
 		// see if the origin of the line lies on both planes
 		assertEquals(0, UtilPlane3D_F64.evaluate(a,line.p), GrlConstants.TEST_F64);
@@ -107,27 +107,27 @@ public class TestIntersection3D_F64 {
 
 		// degenerate triangle
 		Triangle3D_F64 triangle = new Triangle3D_F64(1,1,1,2,2,2,3,3,3);
-		assertEquals(-1,Intersection3D_F64.intersect(triangle,ls,p));
+		assertEquals(-1,Intersection3D_F64.intersection(triangle,ls,p));
 
 		// no intersection
-		triangle.set(1,0,0,  3,0,0,  3,2,0);
-		ls.set(0,0,0,  0,0,10); // completely miss
-		assertEquals(0, Intersection3D_F64.intersect(triangle, ls, p));
-		ls.set(0,0,0,  0,0,10); // hits the plain but not the triangle
-		assertEquals(0, Intersection3D_F64.intersect(triangle, ls, p));
-		ls.set(2,0.5,-1,  2,0.5,-0.5); // would hit, but is too short
-		assertEquals(0, Intersection3D_F64.intersect(triangle, ls, p));
-		ls.set(2,0.5,-0.5,  2,0.5,-1); // would hit, but is too short
-		assertEquals(0,Intersection3D_F64.intersect(triangle,ls,p));
+		triangle.setTo(1,0,0,  3,0,0,  3,2,0);
+		ls.setTo(0,0,0,  0,0,10); // completely miss
+		assertEquals(0, Intersection3D_F64.intersection(triangle, ls, p));
+		ls.setTo(0,0,0,  0,0,10); // hits the plain but not the triangle
+		assertEquals(0, Intersection3D_F64.intersection(triangle, ls, p));
+		ls.setTo(2,0.5,-1,  2,0.5,-0.5); // would hit, but is too short
+		assertEquals(0, Intersection3D_F64.intersection(triangle, ls, p));
+		ls.setTo(2,0.5,-0.5,  2,0.5,-1); // would hit, but is too short
+		assertEquals(0,Intersection3D_F64.intersection(triangle,ls,p));
 
 		// unique intersection
-		ls.set(2,0.5,1,  2,0.5,-1);
-		assertEquals(1,Intersection3D_F64.intersect(triangle,ls,p));
+		ls.setTo(2,0.5,1,  2,0.5,-1);
+		assertEquals(1,Intersection3D_F64.intersection(triangle,ls,p));
 		assertEquals(0,p.distance(new Point3D_F64(2,0.5,0)),GrlConstants.TEST_F64);
 
 		// infinite intersections
-		ls.set(0, 0, 0, 4, 0, 0);
-		assertEquals(2,Intersection3D_F64.intersect(triangle, ls, p));
+		ls.setTo(0, 0, 0, 4, 0, 0);
+		assertEquals(2,Intersection3D_F64.intersection(triangle, ls, p));
 	}
 
 	@Test
@@ -138,27 +138,27 @@ public class TestIntersection3D_F64 {
 
 		// degenerate triangle
 		Triangle3D_F64 triangle = new Triangle3D_F64(1,1,1,2,2,2,3,3,3);
-		assertEquals(-1,Intersection3D_F64.intersect(triangle,line,p));
+		assertEquals(-1,Intersection3D_F64.intersection(triangle,line,p));
 
 		// no intersection
-		triangle.set(1,0,0,  3,0,0,  3,2,0);
-		line.set(0,0,0,  0,0,10); // completely miss
-		assertEquals(0, Intersection3D_F64.intersect(triangle, line, p));
-		line.set(0,0,0,  0,0,10); // hits the plain but not the triangle
-		assertEquals(0, Intersection3D_F64.intersect(triangle, line, p));
+		triangle.setTo(1,0,0,  3,0,0,  3,2,0);
+		line.setTo(0,0,0,  0,0,10); // completely miss
+		assertEquals(0, Intersection3D_F64.intersection(triangle, line, p));
+		line.setTo(0,0,0,  0,0,10); // hits the plain but not the triangle
+		assertEquals(0, Intersection3D_F64.intersection(triangle, line, p));
 
 		// unique intersection - positive
-		line.set(2,0.5,1,  0,0,-2);
-		assertEquals(1,Intersection3D_F64.intersect(triangle,line,p));
+		line.setTo(2,0.5,1,  0,0,-2);
+		assertEquals(1,Intersection3D_F64.intersection(triangle,line,p));
 		assertEquals(0,p.distance(new Point3D_F64(2,0.5,0)),GrlConstants.TEST_F64);
 		// unique intersection - negative
-		line.set(2,0.5,-1,  0,0,2);
-		assertEquals(1,Intersection3D_F64.intersect(triangle,line,p));
+		line.setTo(2,0.5,-1,  0,0,2);
+		assertEquals(1,Intersection3D_F64.intersection(triangle,line,p));
 		assertEquals(0,p.distance(new Point3D_F64(2,0.5,0)),GrlConstants.TEST_F64);
 
 		// infinite intersections
-		line.set(0, 0, 0, 4, 0, 0);
-		assertEquals(2,Intersection3D_F64.intersect(triangle, line, p));
+		line.setTo(0, 0, 0, 4, 0, 0);
+		assertEquals(2,Intersection3D_F64.intersection(triangle, line, p));
 	}
 
 	@Test
@@ -176,24 +176,24 @@ public class TestIntersection3D_F64 {
 		Point3D_F64 found = new Point3D_F64();
 //		assertEquals(1,Intersection3D_F64.intersectConvex(polygon,line,found));
 //		assertTrue(found.distance(-0.5,0.5,2) <= GrlConstants.TEST_F64);
-		line.p.set(0.5,-0.5,0);
+		line.p.setTo(0.5,-0.5,0);
 		assertEquals(1,Intersection3D_F64.intersectConvex(polygon,line,found));
 		assertTrue(found.distance(0.5,-0.5,2) <= GrlConstants.TEST_F64);
 		// point the line in the other direction
-		line.slope.set(0,0,-1);
+		line.slope.setTo(0,0,-1);
 		assertEquals(3,Intersection3D_F64.intersectConvex(polygon,line,found));
 		assertTrue(found.distance(0.5,-0.5,2) <= GrlConstants.TEST_F64);
 		// miss the target entirely
-		line.slope.set(0,50,0.001);
+		line.slope.setTo(0,50,0.001);
 		assertEquals(0,Intersection3D_F64.intersectConvex(polygon,line,found));
 
 		// rotate everything
 		Se3_F64 se = new Se3_F64();
-		se.T.set(-4,2,1.2);
+		se.T.setTo(-4,2,1.2);
 		ConvertRotation3D_F64.eulerToMatrix(EulerType.XYZ,1.2,0.5,3.4,se.R);
 
-		line.p.set(0.5,-0.5,0);
-		line.slope.set(0,0,1);
+		line.p.setTo(0.5,-0.5,0);
+		line.slope.setTo(0,0,1);
 		SePointOps_F64.transform(se,line.p,line.p);
 		GeometryMath_F64.mult(se.R,line.slope,line.slope);
 
@@ -294,20 +294,20 @@ public class TestIntersection3D_F64 {
 	@Test
 	void intersect_1d() {
 		// identical
-		assertTrue(Intersection3D_F64.intersect(0,0,1,1));
+		assertTrue(Intersection3D_F64.intersection(0,0,1,1));
 		// bigger
-		assertTrue(Intersection3D_F64.intersect(0,-1,1,2));
-		assertTrue(Intersection3D_F64.intersect(-1,0,2,1));
+		assertTrue(Intersection3D_F64.intersection(0,-1,1,2));
+		assertTrue(Intersection3D_F64.intersection(-1,0,2,1));
 		// shifted
-		assertTrue(Intersection3D_F64.intersect(0,0.1,1,1.1));
-		assertTrue(Intersection3D_F64.intersect(0,-0.1,1,0.9));
-		assertTrue(Intersection3D_F64.intersect(0.1,0,1.1,1));
-		assertTrue(Intersection3D_F64.intersect(-0.1,0,0.9,1));
+		assertTrue(Intersection3D_F64.intersection(0,0.1,1,1.1));
+		assertTrue(Intersection3D_F64.intersection(0,-0.1,1,0.9));
+		assertTrue(Intersection3D_F64.intersection(0.1,0,1.1,1));
+		assertTrue(Intersection3D_F64.intersection(-0.1,0,0.9,1));
 		// graze
-		assertFalse(Intersection3D_F64.intersect(0,1,1,2));
-		assertFalse(Intersection3D_F64.intersect(1,0,2,1));
+		assertFalse(Intersection3D_F64.intersection(0,1,1,2));
+		assertFalse(Intersection3D_F64.intersection(1,0,2,1));
 		// outside
-		assertFalse(Intersection3D_F64.intersect(0,2,1,3));
+		assertFalse(Intersection3D_F64.intersection(0,2,1,3));
 	}
 
 	@Test
@@ -316,11 +316,11 @@ public class TestIntersection3D_F64 {
 		Point3D_F64 b = new Point3D_F64();
 
 		// test a negative case first
-		assertFalse(Intersection3D_F64.intersect(
+		assertFalse(Intersection3D_F64.intersection(
 				new LineParametric3D_F64(0,0,-10,1,0,0),new Sphere3D_F64(0,0,0,2),a,b));
 
 		// Now a positive case
-		assertTrue(Intersection3D_F64.intersect(
+		assertTrue(Intersection3D_F64.intersection(
 				new LineParametric3D_F64(0,0,2,1,0,0),new Sphere3D_F64(0,0,2,2),a,b));
 		assertTrue( a.distance(new Point3D_F64( 2,0,2)) <= GrlConstants.TEST_F64);
 		assertTrue( b.distance(new Point3D_F64(-2,0,2)) <= GrlConstants.TEST_F64);
@@ -331,14 +331,14 @@ public class TestIntersection3D_F64 {
 	 */
 	@Test
 	void intersectConvex() {
-		FastQueue<Point3D_F64> polygon = new FastQueue<>(Point3D_F64::new);
-		polygon.grow().set(-1,-1.2,2);
-		polygon.grow().set(-1,1.2,2);
-		polygon.grow().set(1,1.2,2);
-		polygon.grow().set(1,-1.2,2);
+		DogArray<Point3D_F64> polygon = new DogArray<>(Point3D_F64::new);
+		polygon.grow().setTo(-1,-1.2,2);
+		polygon.grow().setTo(-1,1.2,2);
+		polygon.grow().setTo(1,1.2,2);
+		polygon.grow().setTo(1,-1.2,2);
 
 		LineParametric3D_F64 line = new LineParametric3D_F64();
-		line.slope.set(0,0,1);
+		line.slope.setTo(0,0,1);
 
 		Point3D_F64 found = new Point3D_F64();
 
@@ -347,55 +347,85 @@ public class TestIntersection3D_F64 {
 		assertEquals(0,found.distance(0,0,2), UtilEjml.TEST_F64);
 
 		// negative intersection
-		line.slope.set(0,0,-1);
+		line.slope.setTo(0,0,-1);
 		assertEquals(3,Intersection3D_F64.intersectConvex(polygon,line,found));
 		assertEquals(0,found.distance(0,0,2), UtilEjml.TEST_F64);
 
 		// should barely hit
-		line.slope.set(-1,0,2.01);
+		line.slope.setTo(-1,0,2.01);
 		assertEquals(1,Intersection3D_F64.intersectConvex(polygon,line,found));
 		assertEquals(0,found.distance(-1*(2.0/2.01),0,2), UtilEjml.TEST_F64);
-		line.slope.set(1,0,2.01);
+		line.slope.setTo(1,0,2.01);
 		assertEquals(1,Intersection3D_F64.intersectConvex(polygon,line,found));
 		assertEquals(0,found.distance(1*(2.0/2.01),0,2), UtilEjml.TEST_F64);
-		line.slope.set(0,-1.2,2.01);
+		line.slope.setTo(0,-1.2,2.01);
 		assertEquals(1,Intersection3D_F64.intersectConvex(polygon,line,found));
 		assertEquals(0,found.distance(0,-1.2*(2.0/2.01),2), UtilEjml.TEST_F64);
-		line.slope.set(0,1.2,2.01);
+		line.slope.setTo(0,1.2,2.01);
 		assertEquals(1,Intersection3D_F64.intersectConvex(polygon,line,found));
 		assertEquals(0,found.distance(0,1.2*(2.0/2.01),2), UtilEjml.TEST_F64);
 
 		// should barely miss
-		line.slope.set(-1,0,1.99);
+		line.slope.setTo(-1,0,1.99);
 		assertEquals(0,Intersection3D_F64.intersectConvex(polygon,line,found));
-		line.slope.set(1,0,1.99);
+		line.slope.setTo(1,0,1.99);
 		assertEquals(0,Intersection3D_F64.intersectConvex(polygon,line,found));
-		line.slope.set(0,-1.2,1.99);
+		line.slope.setTo(0,-1.2,1.99);
 		assertEquals(0,Intersection3D_F64.intersectConvex(polygon,line,found));
-		line.slope.set(0,1.2,1.99);
+		line.slope.setTo(0,1.2,1.99);
 		assertEquals(0,Intersection3D_F64.intersectConvex(polygon,line,found));
 
 		// scale sanity check
-		line.slope.set(-1,0,2.01);
+		line.slope.setTo(-1,0,2.01);
 		line.slope.normalize();
 		assertEquals(1,Intersection3D_F64.intersectConvex(polygon,line,found));
 		assertEquals(0,found.distance(-1*(2.0/2.01),0,2), UtilEjml.TEST_F64);
-		line.slope.set(-1,0,1.99);
+		line.slope.setTo(-1,0,1.99);
 		line.slope.normalize();
 		assertEquals(0,Intersection3D_F64.intersectConvex(polygon,line,found));
 
 		// see if polygon order matters
-		polygon.get(0).set(1,-1.2,2);
-		polygon.get(1).set(1,1.2,2);
-		polygon.get(2).set(-1,1.2,2);
-		polygon.get(3).set(-1,-1.2,2);
+		polygon.get(0).setTo(1,-1.2,2);
+		polygon.get(1).setTo(1,1.2,2);
+		polygon.get(2).setTo(-1,1.2,2);
+		polygon.get(3).setTo(-1,-1.2,2);
 
-		line.slope.set(-1,0,2.01);
+		line.slope.setTo(-1,0,2.01);
 		line.slope.normalize();
 		assertEquals(1,Intersection3D_F64.intersectConvex(polygon,line,found));
 		assertEquals(0,found.distance(-1*(2.0/2.01),0,2), UtilEjml.TEST_F64);
-		line.slope.set(-1,0,1.99);
+		line.slope.setTo(-1,0,1.99);
 		line.slope.normalize();
 		assertEquals(0,Intersection3D_F64.intersectConvex(polygon,line,found));
 	}
+
+	@Test void intersectionArea_box_box() {
+		// check several positive cases
+		check( new Box3D_F64(0,0,0,100,120,90),new Box3D_F64(0,0,0,100,120,90), 100*120*90);
+		check( new Box3D_F64(0,0,0,100,120,90),new Box3D_F64(10,12,13,99,119,89), 89*107*76);
+		check( new Box3D_F64(0,0,0,100,120,90),new Box3D_F64(50,50,50,200,200,200), 50*70*40 );
+		check( new Box3D_F64(0,0,0,100,120,90),new Box3D_F64(-10,-10,-10,10,10,10), 10*10*10 );
+		check( new Box3D_F64(0,0,0,100,120,90),new Box3D_F64(90,-10,30,105,1,75), 10*1*45);
+		check( new Box3D_F64(0,0,0,100,120,90),new Box3D_F64(90,5,-5,105,105,105), 10*100*90 );
+
+		// negative cases
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(200, 200, 200,300, 305,295), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(-200, -200, -200,-10, -10,-10), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(0, -20, -30, 100, -5, 5), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(0, 125, 95, 100, 130, 100), 0);
+
+		// edge cases
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(0, 0, 0, 0, 0, 0), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(100, 120, 90, 100, 120, 90), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(-10, 0, 0, 0, 120, 90), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(100, 0, 0, 105, 120, 90), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(0, -10, 0, 100, 0, 90), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(0, 120, 0, 100, 125, 90), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(0, 0, 90, 100, 120, 95), 0);
+		check(new Box3D_F64(0,0,0,100,120,90), new Box3D_F64(0, 0, -10, 100, 120, 0), 0);
+	}
+
+	private void check( Box3D_F64 a , Box3D_F64 b , double expected ) {
+		assertEquals(expected,Intersection3D_F64.intersectionArea(a,b),GrlConstants.TEST_F64);
+	}
 }
