@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -20,6 +20,7 @@ package georegression.struct.point;
 
 import georegression.misc.GrlConstants;
 import georegression.struct.GeoTuple3D_F64;
+import org.junit.jupiter.api.Test;
 
 import java.util.Random;
 
@@ -29,19 +30,20 @@ import static org.junit.jupiter.api.Assertions.*;
 /**
  * @author Peter Abeles
  */
-@SuppressWarnings({"unchecked"})
-public class GenericGeoTupleTests3D_F64 <T extends GeoTuple3D_F64> extends GenericGeoTupleTests_F64<T> {
+@SuppressWarnings({"unchecked","NullAway.Init"})
+public abstract class GenericGeoTupleTests3D_F64 <T extends GeoTuple3D_F64> extends GenericGeoTupleTests_F64<T> {
 
 	Random rand = new Random(234234);
 	private T seed;
 
-	public GenericGeoTupleTests3D_F64( T seed ) {
-		super( seed );
+	protected GenericGeoTupleTests3D_F64( T seed ) {
+		super( seed , 3);
 		this.seed = seed;
 	}
 
+	@Override
 	public void checkAll() {
-		super.checkAll( 3 );
+		super.checkAll();
 		checkGetAndSetAxis();
 		checkSetAxisAll();
 		isIdentical_3_double();
@@ -49,6 +51,7 @@ public class GenericGeoTupleTests3D_F64 <T extends GeoTuple3D_F64> extends Gener
 		isNaN();
 	}
 
+	@Test
 	public void checkGetAndSetAxis() {
 		T a = (T) seed.createNewInstance();
 
@@ -63,46 +66,50 @@ public class GenericGeoTupleTests3D_F64 <T extends GeoTuple3D_F64> extends Gener
 		assertEquals( 1.5, a.getZ(), GrlConstants.TEST_F64);
 	}
 
+	@Test
 	public void checkSetAxisAll() {
 		T a = (T) seed.createNewInstance();
 
-		a.set( 1.5, 2.5, 3.5 );
+		a.setTo( 1.5, 2.5, 3.5 );
 
 		assertEquals( 1.5, a.getX(), GrlConstants.TEST_F64);
 		assertEquals( 2.5, a.getY(), GrlConstants.TEST_F64);
 		assertEquals( 3.5, a.getZ(), GrlConstants.TEST_F64);
 	}
 
+	@Test
 	public void isIdentical_3_double() {
 		T a = (T) seed.createNewInstance();
 
-		a.set( 1, 2, 3 );
+		a.setTo( 1, 2, 3 );
 
 		assertTrue( a.isIdentical( 1, 2, 3, GrlConstants.TEST_F64) );
 	}
 
+	@Test
 	public void isIdentical_tuple() {
 		T a = (T) seed.createNewInstance();
 
-		a.set( 1, 2, 3 );
+		a.setTo( 1, 2, 3 );
 
 		T b = (T) a.copy();
 
 		assertTrue( a.isIdentical( b, GrlConstants.TEST_F64) );
 	}
 
+	@Test
 	public void isNaN() {
 		T a = (T) seed.createNewInstance();
 
-		a.set( 1, 2, 3 );
+		a.setTo( 1, 2, 3 );
 
 		assertFalse( a.isNaN() );
 
-		a.set( 1, 2, Double.NaN );
+		a.setTo( 1, 2, Double.NaN );
 		assertTrue( a.isNaN() );
-		a.set( 1, Double.NaN, 3 );
+		a.setTo( 1, Double.NaN, 3 );
 		assertTrue( a.isNaN() );
-		a.set( Double.NaN, 1, 3 );
+		a.setTo( Double.NaN, 1, 3 );
 		assertTrue( a.isNaN() );
 	}
 
