@@ -20,7 +20,7 @@ package georegression.struct.point;
 
 import org.junit.jupiter.api.Test;
 
-import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
 
 /**
  * @author Peter Abeles
@@ -31,17 +31,12 @@ public class TestPoint3D_F64 extends GenericGeoTupleTests3D_F64<Point3D_F64> {
 		super( new Point3D_F64() );
 	}
 
-	@Test
-	void generic() {
-		checkAll();
-	}
-
 	@Test
 	void equals_vector() {
 		Point3D_F64 a = new Point3D_F64();
 		Vector3D_F64 b = new Vector3D_F64();
 
 		// numerically they are identical, but not the same type so this should fail
-		assertFalse(a.equals(b));
+		assertNotEquals(a, b);
 	}
 }
