@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020, Peter Abeles. All Rights Reserved.
+ * Copyright (C) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Geometric Regression Library (GeoRegression).
  *
@@ -57,7 +57,7 @@ public class TestBox3D_F64 {
 	@Test
 	void set_box() {
 		Box3D_F64 box = new Box3D_F64();
-		box.set(1,2,3,4,5,6);
+		box.setTo(1,2,3,4,5,6);
 
 		assertEquals(1,box.p0.x, GrlConstants.TEST_F64);
 		assertEquals(2,box.p0.y, GrlConstants.TEST_F64);
@@ -71,7 +71,7 @@ public class TestBox3D_F64 {
 	void set_floats() {
 		Box3D_F64 boxA = new Box3D_F64(1,2,3,4,5,6);
 		Box3D_F64 box = new Box3D_F64();
-		box.set(boxA);
+		box.setTo(boxA);
 
 		assertEquals(1,box.p0.x, GrlConstants.TEST_F64);
 		assertEquals(2,box.p0.y, GrlConstants.TEST_F64);
